==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesHil.php <==
<?php
/** Hiligaynon (Ilonggo)
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Kguirnela
 */

$messages = array(
# User preference toggles
'tog-underline'        => 'Kuritan sa idalom ang mga tabid:',
'tog-highlightbroken'  => 'Dagwayi ang utod nga tabid <a href="" class="new">nga nagaka anggid sini </a> (alternatibo: anggid sini<a href="" class="internal">?</a>).',
'tog-justify'          => 'Tadlongon ang mga parapo',
'tog-rememberpassword' => 'Dumdumon ang akon pagsulod sa sini nga kompyuter',

'skinpreview' => '(Ipakita subong)',

# Dates
'sunday'        => 'Domingo',
'monday'        => 'Lunes',
'tuesday'       => 'Martes',
'wednesday'     => 'Miyerkoles',
'thursday'      => 'Huebes',
'friday'        => 'Biyernes',
'saturday'      => 'Sabado',
'sun'           => 'Dom',
'mon'           => 'Lun',
'tue'           => 'Mar',
'wed'           => 'Miy',
'thu'           => 'Hue',
'fri'           => 'Biy',
'sat'           => 'Sab',
'january'       => 'Enero',
'february'      => 'Pebrero',
'march'         => 'Marso',
'april'         => 'Abril',
'may_long'      => 'Mayo',
'june'          => 'Hunyo',
'july'          => 'Hulyo',
'august'        => 'Agosto',
'september'     => 'Septiyembre',
'october'       => 'Oktubre',
'november'      => 'Nobiyembre',
'december'      => 'Disyimbre',
'january-gen'   => 'Enero',
'february-gen'  => 'Pebrero',
'march-gen'     => 'Marso',
'april-gen'     => 'Abril',
'may-gen'       => 'Mayo',
'june-gen'      => 'Hunyo',
'july-gen'      => 'Hulyo',
'august-gen'    => 'Agosto',
'september-gen' => 'Septiyembre',
'october-gen'   => 'Oktubre',
'november-gen'  => 'Nobiyembre',
'december-gen'  => 'Disyimbre',
'jan'           => 'Ene',
'feb'           => 'Peb',
'mar'           => 'Mar',
'apr'           => 'Abr',
'may'           => 'May',
'jun'           => 'Hun',
'jul'           => 'Hul',
'aug'           => 'Ago',
'sep'           => 'Sep',
'oct'           => 'Okt',
'nov'           => 'Nob',
'dec'           => 'Dis',

'about'          => 'Nahanungod',
'cancel'         => 'Kanselahon',
'qbfind'         => 'Pangita',
'qbedit'         => 'Ilisan',
'qbpageoptions'  => 'Ining panid',
'qbspecialpages' => 'Pinasahi nga mga panid',
'mytalk'         => 'Akon paghisayranay',
'navigation'     => 'Nabigayson',
'and'            => 'kag',

'tagline'          => 'Halin sa {{SITENAME}}',
'help'             => 'Bulig',
'search'           => 'Pangita-a',
'searchbutton'     => 'Pangita-a',
'go'               => 'Lakat',
'searcharticle'    => 'Lakat',
'history_short'    => 'Saysay',
'printableversion' => 'Pang-imprinta nga bersyon',
'permalink'        => 'Unay nga tabid',
'edit'             => 'Ilisan',
'delete'           => 'Panason',
'protect'          => 'Pangapinan',
'talkpagelinktext' => 'Hisayranay',
'personaltools'    => 'Mga kinaugalingon nga galamiton',
'talk'             => 'Paghisayranay',
'views'            => 'Mga talanawon',
'toolbox'          => 'Mga galamiton',
'otherlanguages'   => 'Sa iban nga lenguahe',
'jumpto'           => 'Lumpat sa:',
'jumptonavigation' => 'nabigayson',
'jumptosearch'     => 'Pangita-a',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Nahanungod sa {{SITENAME}}',
'aboutpage'            => 'Project:Nahanungod',
'currentevents'        => 'Mga Hitabo Subong',
'disclaimers'          => 'Diskleymer',
'disclaimerpage'       => 'Project:Kabilogan nga diskleymer',
'edithelp'             => 'Bulig sa pag Ilis',
'mainpage'             => 'Mayor nga Panid',
'mainpage-description' => 'Mayor nga Panid',
'portal'               => 'Portal sang Banwa',
'privacy'              => 'Polisa sa Pribisidad',
'privacypage'          => 'Project:Polisa sa Pribisidad',

'retrievedfrom'           => 'Ginkuha halin sa "$1"',
'youhavenewmessages'      => 'Ikaw may $1 ($2).',
'newmessageslink'         => 'mga bag-ong mensahe',
'youhavenewmessagesmulti' => 'May mga bag-ong mensahe ka sa $1',
'editsection'             => 'ilisan',
'editold'                 => 'ilisan',
'editsectionhint'         => 'Islan ining bahin: $1',
'site-rss-feed'           => '$1 RSS Feed',
'site-atom-feed'          => '$1 Atom Feed',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user' => 'Panid sang Manog-gamit',

# General errors
'viewsource' => 'Lantawon ang ginhalinan',

# Login and logout pages
'welcomecreation'         => '== Pagtamyaw, $1! == 
Ang imo account nahimo na. 
Indi pagkalimti ang pag ilis sang imo mga pagpasulabi sa {{SITENAME}}.',
'yourname'                => 'Ngalan sang Manog-gamit:',
'yourpassword'            => 'Kontra-senyas:',
'yourpasswordagain'       => 'Suliton ang kontra-senyas:',
'remembermypassword'      => 'Dumdumon ang akon pagsulod sa sini nga kompyuter',
'login'                   => 'Mag sulod',
'nav-login-createaccount' => 'Magsulod / maghimo account',
'userlogin'               => 'Mag sulod / maghimo account',
'userlogout'              => 'Mag guha',
'notloggedin'             => 'Wala naka-sulod',
'nologinlink'             => 'Maghimo account',
'createaccount'           => 'Maghimo Account',
'gotaccountlink'          => 'Mag sulod',
'youremail'               => 'E-mail:',
'username'                => 'Ngalan sang Manog-gamit:',
'email'                   => 'E-mail',

# Edit pages
'summary'            => 'Kabilogan',
'minoredit'          => 'Ini menor nga pag-ilis',
'watchthis'          => 'Bantayan ining panid',
'savearticle'        => 'Tiponon ining panid',
'preview'            => 'Ipakita subong',
'showpreview'        => 'Ipakita nga daan',
'showdiff'           => 'Ipakita ang inislan',
'whitelistedittitle' => 'Ang pag sulod kinahanglan agud maka ilis',
'loginreqlink'       => 'mag sulod',

# History pages
'currentrev'          => 'Mga Inislan Subong',
'currentrevisionlink' => 'Mga Inislan Subong',
'cur'                 => 'karon',
'last'                => 'ulihi',
'page_last'           => 'ulihi',

# Diffs
'editundo' => 'bawi-on ang pag ilis',

# Search results
'powersearch'        => 'Abanse nga pagpangita',
'powersearch-legend' => 'Abanse nga pagpangita',

# Preferences page
'mypreferences'     => 'Akon pagpalabi',
'prefsnologin'      => 'Wala naka-sulod',
'prefs-rc'          => 'Mga Bag-o nga Inislan',
'searchresultshead' => 'Pangita-a',

# Recent changes
'recentchanges' => 'Mga Bag-o nga Inislan',
'newpageletter' => 'B',

# Recent changes linked
'recentchangeslinked' => 'May labot nga pag-ilis',

# Upload
'upload'            => 'Karga file',
'uploadbtn'         => 'Karga file',
'uploadnologin'     => 'Wala naka-sulod',
'filedesc'          => 'Kabilogan',
'fileuploadsummary' => 'Kabilogan:',
'watchthisupload'   => 'Bantayan ining panid',

# File deletion
'filedelete-submit' => 'Panason',

# Random page
'randompage' => 'Lagpat nga Panid',

'brokenredirects-edit'   => '(ilisan)',
'brokenredirects-delete' => '(panason)',

# Miscellaneous special pages
'newpages-username' => 'Ngalan sang Manog-gamit:',
'move'              => 'Saylohon',
'movethispage'      => 'Saylohon ining panid',

# Book sources
'booksources-go' => 'Lakat',

# Special:Log
'log-search-submit' => 'Lakat',

# Special:AllPages
'alphaindexline' => '$1 sa $2',
'allpagessubmit' => 'Sige',

# Watchlist
'watchlist'     => 'Akon Ginabantayan',
'mywatchlist'   => 'Akon Ginabantayan',
'watchnologin'  => 'Wala naka-sulod',
'watch'         => 'Bantayan',
'watchthispage' => 'Bantayan ining panid',

# Delete/protect/revert
'delete-legend' => 'Panason',

# Restrictions (nouns)
'restriction-edit' => 'Ilisan',
'restriction-move' => 'Saylohon',

# Undelete
'undelete-search-submit' => 'Pangita-a',

# Contributions
'mycontris' => 'Akon contribusyon',

'sp-contributions-submit' => 'Pangita-a',

# What links here
'whatlinkshere'       => 'Ang naga-tabid diri',
'whatlinkshere-title' => 'Mga panid nga naga tabid sa $1',

# Block/unblock
'ipbreason'          => 'Rason:',
'ipblocklist-submit' => 'Pangita-a',
'contribslink'       => 'contribuyson',

# Move page
'move-page-legend' => 'Saylohon ining panid',
'movearticle'      => 'Saylohon ining panid:',
'move-watch'       => 'Bantayan ining panid',
'movepagebtn'      => 'Saylohon ining panid',
'movedto'          => 'gin saylo sa',
'1movedto2'        => '[[$1]] gin saylo na sa [[$2]]',
'movereason'       => 'Rason:',

# Namespace 8 related
'allmessages' => 'Mga mensahe sang sistema',

# Tooltip help for the actions
'tooltip-pt-userpage'     => 'Akon panid',
'tooltip-pt-mytalk'       => 'Akon panid sang paghisayranay',
'tooltip-pt-preferences'  => 'Akon pagpalabi',
'tooltip-pt-login'        => 'Gina-abi-abi ikaw nga man magsulod paagi sa pag log-in, apang indi ini kinahanglan gid buhaton',
'tooltip-ca-talk'         => 'Paghisayranay nahanungod sini nga panid',
'tooltip-ca-edit'         => 'Puede nimo islan ang unod sang sini nga panid. Palihog gamit sang preview button antes permanentehon ang gin ilisan.',
'tooltip-ca-move'         => 'Saylohon ining panid',
'tooltip-search'          => 'Pangita-a sa {{SITENAME}}',
'tooltip-p-logo'          => 'Mayor nga Panid',
'tooltip-n-mainpage'      => 'Magdu-aw sa Mayor nga Panid',
'tooltip-n-portal'        => 'Nahanungod sa poryekto, ano ang imo mahimo, di-in makatukib',
'tooltip-n-recentchanges' => 'Ang listahan sang mga bag-o inislan sa wiki.',
'tooltip-n-randompage'    => 'Magbasa sang isa ka panid paagi sa lagpat',
'tooltip-n-help'          => 'Ang lugar para maka tukib.',
'tooltip-t-whatlinkshere' => 'Listahan sang tanan nga panid sang wiki nga naga tabid diri',
'tooltip-t-upload'        => 'Mag karga mga files',
'tooltip-t-specialpages'  => 'Lista sang tanan nga espesyal nga panid',
'tooltip-save'            => 'Permanentehon ang imo gin islan',

# Media information
'show-big-image' => 'Kabilogan nga resolusyon',

# Special:NewImages
'ilsubmit' => 'Pangita-a',

# 'all' in various places, this might be different for inflected languages
'namespacesall' => 'tanan',

# Multipage image navigation
'imgmultigo' => 'Lakat',

# Table pager
'table_pager_limit_submit' => 'Lakat',

# Special:Version
'version-specialpages' => 'Pinasahi nga mga panid',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Pangita-a',

# Special:SpecialPages
'specialpages' => 'Pinasahi nga mga panid',

);

==> mediawiki-1.15.0rc1.tar.gz: mediawiki-1.15.0rc1/languages/messages/MessagesHil.php <==
<?php
/** Hiligaynon (Ilonggo)
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Kguirnela
 */

$messages = array(
# User preference toggles
'tog-underline'        => 'Kuritan sa idalom ang mga tabid:',
'tog-highlightbroken'  => 'Dagwayi ang utod nga tabid <a href="" class="new">nga nagaka anggid sini </a> (alternatibo: anggid sini<a href="" class="internal">?</a>).',
'tog-justify'          => 'Tadlongon ang mga parapo',
'tog-rememberpassword' => 'Dumdumon ang akon pagsulod sa sini nga kompyuter',

# Dates
'sunday'        => 'Domingo',
'monday'        => 'Lunes',
'tuesday'       => 'Martes',
'wednesday'     => 'Miyerkoles',
'thursday'      => 'Huebes',
'friday'        => 'Biyernes',
'saturday'      => 'Sabado',
'sun'           => 'Dom',
'mon'           => 'Lun',
'tue'           => 'Mar',
'wed'           => 'Miy',
'thu'           => 'Hue',
'fri'           => 'Biy',
'sat'           => 'Sab',
'january'       => 'Enero',
'february'      => 'Pebrero',
'march'         => 'Marso',
'april'         => 'Abril',
'may_long'      => 'Mayo',
'june'          => 'Hunyo',
'july'          => 'Hulyo',
'august'        => 'Agosto',
'september'     => 'Septiyembre',
'october'       => 'Oktubre',
'november'      => 'Nobiyembre',
'december'      => 'Disyimbre',
'january-gen'   => 'Enero',
'february-gen'  => 'Pebrero',
'march-gen'     => 'Marso',
'april-gen'     => 'Abril',
'may-gen'       => 'Mayo',
'june-gen'      => 'Hunyo',
'july-gen'      => 'Hulyo',
'august-gen'    => 'Agosto',
'september-gen' => 'Septiyembre',
'october-gen'   => 'Oktubre',
'november-gen'  => 'Nobiyembre',
'december-gen'  => 'Disyimbre',
'jan'           => 'Ene',
'feb'           => 'Peb',
'mar'           => 'Mar',
'apr'           => 'Abr',
'may'           => 'May',
'jun'           => 'Hun',
'jul'           => 'Hul',
'aug'           => 'Ago',
'sep'           => 'Sep',
'oct'           => 'Okt',
'nov'           => 'Nob',
'dec'           => 'Dis',

'about'          => 'Nahanungod',
'cancel'         => 'Kanselahon',
'qbfind'         => 'Pangita',
'qbedit'         => 'Ilisan',
'qbpageoptions'  => 'Ining panid',
'qbspecialpages' => 'Pinasahi nga mga panid',
'mytalk'         => 'Akon paghisayranay',
'navigation'     => 'Nabigayson',
'and'            => '&#32;kag',

'tagline'          => 'Halin sa {{SITENAME}}',
'help'             => 'Bulig',
'search'           => 'Pangita-a',
'searchbutton'     => 'Pangita-a',
'go'               => 'Lakat',
'searcharticle'    => 'Lakat',
'history_short'    => 'Saysay',
'printableversion' => 'Pang-imprinta nga bersyon',
'permalink'        => 'Unay nga tabid',
'edit'             => 'Ilisan',
'delete'           => 'Panason',
'protect'          => 'Pangapinan',
'talkpagelinktext' => 'Hisayranay',
'personaltools'    => 'Mga kinaugalingon nga galamiton',
'talk'             => 'Paghisayranay',
'views'            => 'Mga talanawon',
'toolbox'          => 'Mga galamiton',
'otherlanguages'   => 'Sa iban nga lenguahe',
'jumpto'           => 'Lumpat sa:',
'jumptonavigation' => 'nabigayson',
'jumptosearch'     => 'Pangita-a',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Nahanungod sa {{SITENAME}}',
'aboutpage'            => 'Project:Nahanungod',
'currentevents'        => 'Mga Hitabo Subong',
'disclaimers'          => 'Diskleymer',
'disclaimerpage'       => 'Project:Kabilogan nga diskleymer',
'edithelp'             => 'Bulig sa pag Ilis',
'mainpage'             => 'Mayor nga Panid',
'mainpage-description' => 'Mayor nga Panid',
'portal'               => 'Portal sang Banwa',
'privacy'              => 'Polisa sa Pribisidad',
'privacypage'          => 'Project:Polisa sa Pribisidad',

'retrievedfrom'           => 'Ginkuha halin sa "$1"',
'youhavenewmessages'      => 'Ikaw may $1 ($2).',
'newmessageslink'         => 'mga bag-ong mensahe',
'youhavenewmessagesmulti' => 'May mga bag-ong mensahe ka sa $1',
'editsection'             => 'ilisan',
'editold'                 => 'ilisan',
'editsectionhint'         => 'Islan ining bahin: $1',
'site-rss-feed'           => '$1 RSS Feed',
'site-atom-feed'          => '$1 Atom Feed',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user' => 'Panid sang Manog-gamit',

# General errors
'viewsource' => 'Lantawon ang ginhalinan',

# Login and logout pages
'welcomecreation'         => '== Pagtamyaw, $1! == 
Ang imo account nahimo na. 
Indi pagkalimti ang pag ilis sang imo mga pagpasulabi sa {{SITENAME}}.',
'yourname'                => 'Ngalan sang Manog-gamit:',
'yourpassword'            => 'Kontra-senyas:',
'yourpasswordagain'       => 'Suliton ang kontra-senyas:',
'remembermypassword'      => 'Dumdumon ang akon pagsulod sa sini nga kompyuter',
'login'                   => 'Mag sulod',
'nav-login-createaccount' => 'Magsulod / maghimo account',
'userlogin'               => 'Mag sulod / maghimo account',
'userlogout'              => 'Mag guha',
'notloggedin'             => 'Wala naka-sulod',
'nologinlink'             => 'Maghimo account',
'createaccount'           => 'Maghimo Account',
'gotaccountlink'          => 'Mag sulod',
'youremail'               => 'E-mail:',
'username'                => 'Ngalan sang Manog-gamit:',
'email'                   => 'E-mail',

# Edit pages
'summary'            => 'Kabilogan:',
'minoredit'          => 'Ini menor nga pag-ilis',
'watchthis'          => 'Bantayan ining panid',
'savearticle'        => 'Tiponon ining panid',
'preview'            => 'Ipakita subong',
'showpreview'        => 'Ipakita nga daan',
'showdiff'           => 'Ipakita ang inislan',
'whitelistedittitle' => 'Ang pag sulod kinahanglan agud maka ilis',
'loginreqlink'       => 'mag sulod',

# History pages
'currentrev'          => 'Mga Inislan Subong',
'currentrevisionlink' => 'Mga Inislan Subong',
'cur'                 => 'karon',
'last'                => 'ulihi',
'page_last'           => 'ulihi',

# Diffs
'editundo' => 'bawi-on ang pag ilis',

# Search results
'powersearch'        => 'Abanse nga pagpangita',
'powersearch-legend' => 'Abanse nga pagpangita',

# Preferences page
'mypreferences'     => 'Akon pagpalabi',
'prefsnologin'      => 'Wala naka-sulod',
'skin-preview'      => 'Ipakita subong',
'prefs-rc'          => 'Mga Bag-o nga Inislan',
'searchresultshead' => 'Pangita-a',

# Recent changes
'recentchanges' => 'Mga Bag-o nga Inislan',
'newpageletter' => 'B',

# Recent changes linked
'recentchangeslinked' => 'May labot nga pag-ilis',

# Upload
'upload'            => 'Karga file',
'uploadbtn'         => 'Karga file',
'uploadnologin'     => 'Wala naka-sulod',
'filedesc'          => 'Kabilogan',
'fileuploadsummary' => 'Kabilogan:',
'watchthisupload'   => 'Bantayan ining panid',

# File deletion
'filedelete-submit' => 'Panason',

# Random page
'randompage' => 'Lagpat nga Panid',

'brokenredirects-edit'   => '(ilisan)',
'brokenredirects-delete' => '(panason)',

# Miscellaneous special pages
'newpages-username' => 'Ngalan sang Manog-gamit:',
'move'              => 'Saylohon',
'movethispage'      => 'Saylohon ining panid',

# Book sources
'booksources-go' => 'Lakat',

# Special:AllPages
'alphaindexline' => '$1 sa $2',
'allpagessubmit' => 'Sige',

# Special:LinkSearch
'linksearch-ok' => 'Pangita-a',

# Watchlist
'watchlist'     => 'Akon Ginabantayan',
'mywatchlist'   => 'Akon Ginabantayan',
'watchnologin'  => 'Wala naka-sulod',
'watch'         => 'Bantayan',
'watchthispage' => 'Bantayan ining panid',

# Delete
'delete-legend' => 'Panason',

# Protect
'prot_1movedto2' => '[[$1]] gin saylo na sa [[$2]]',

# Restrictions (nouns)
'restriction-edit' => 'Ilisan',
'restriction-move' => 'Saylohon',

# Undelete
'undelete-search-submit' => 'Pangita-a',

# Contributions
'mycontris' => 'Akon contribusyon',

'sp-contributions-submit' => 'Pangita-a',

# What links here
'whatlinkshere'       => 'Ang naga-tabid diri',
'whatlinkshere-title' => 'Mga panid nga naga tabid sa $1',

# Block/unblock
'ipbreason'          => 'Rason:',
'ipblocklist-submit' => 'Pangita-a',
'contribslink'       => 'contribuyson',

# Move page
'move-page-legend' => 'Saylohon ining panid',
'movearticle'      => 'Saylohon ining panid:',
'movenologin'      => 'Wala naka-sulod',
'move-watch'       => 'Bantayan ining panid',
'movepagebtn'      => 'Saylohon ining panid',
'movedto'          => 'gin saylo sa',
'1movedto2'        => '[[$1]] gin saylo na sa [[$2]]',
'movereason'       => 'Rason:',

# Namespace 8 related
'allmessages' => 'Mga mensahe sang sistema',

# Tooltip help for the actions
'tooltip-pt-userpage'     => 'Akon panid',
'tooltip-pt-mytalk'       => 'Akon panid sang paghisayranay',
'tooltip-pt-preferences'  => 'Akon pagpalabi',
'tooltip-pt-login'        => 'Gina-abi-abi ikaw nga man magsulod paagi sa pag log-in, apang indi ini kinahanglan gid buhaton',
'tooltip-ca-talk'         => 'Paghisayranay nahanungod sini nga panid',
'tooltip-ca-edit'         => 'Puede nimo islan ang unod sang sini nga panid. Palihog gamit sang preview button antes permanentehon ang gin ilisan.',
'tooltip-ca-move'         => 'Saylohon ining panid',
'tooltip-search'          => 'Pangita-a sa {{SITENAME}}',
'tooltip-p-logo'          => 'Mayor nga Panid',
'tooltip-n-mainpage'      => 'Magdu-aw sa Mayor nga Panid',
'tooltip-n-portal'        => 'Nahanungod sa poryekto, ano ang imo mahimo, di-in makatukib',
'tooltip-n-recentchanges' => 'Ang listahan sang mga bag-o inislan sa wiki.',
'tooltip-n-randompage'    => 'Magbasa sang isa ka panid paagi sa lagpat',
'tooltip-n-help'          => 'Ang lugar para maka tukib.',
'tooltip-t-whatlinkshere' => 'Listahan sang tanan nga panid sang wiki nga naga tabid diri',
'tooltip-t-upload'        => 'Mag karga mga files',
'tooltip-t-specialpages'  => 'Lista sang tanan nga espesyal nga panid',
'tooltip-save'            => 'Permanentehon ang imo gin islan',

# Media information
'show-big-image' => 'Kabilogan nga resolusyon',

# Special:NewFiles
'ilsubmit' => 'Pangita-a',

# 'all' in various places, this might be different for inflected languages
'namespacesall' => 'tanan',

# Multipage image navigation
'imgmultigo' => 'Lakat',

# Table pager
'table_pager_limit_submit' => 'Lakat',

# Special:Version
'version-specialpages' => 'Pinasahi nga mga panid',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Pangita-a',

# Special:SpecialPages
'specialpages' => 'Pinasahi nga mga panid',

);
